@@ -1,6 +1,6 @@
 package Search::Elasticsearch::Async;
 
-use Search::Elasticsearch 1.11;
+use Search::Elasticsearch 1.12;
 
 use Promises 0.93 ();
 use Moo 1.003;
@@ -8,7 +8,7 @@ extends 'Search::Elasticsearch';
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 #===================================
 sub new {
@@ -41,7 +41,7 @@ Search::Elasticsearch::Async - Async API for Elasticsearch using Promises
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -549,8 +549,8 @@ bodies.  See:
 
 =head1 HELPER MODULES
 
-L<Elasticsearch::Async::Bulk> and L<Elasticsearch::Async::Scroll> are helper
-modules which assist with bulk indexing and scrolled searching, eg:
+L<Search::Elasticsearch::Async::Bulk> and L<Search::Elasticsearch::Async::Scroll>
+are helper modules which assist with bulk indexing and scrolled searching, eg:
 
     $es->scroll_helper(
         index     => 'myindex',
