@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Async::Bulk;
-$Search::Elasticsearch::Async::Bulk::VERSION = '1.11';
+$Search::Elasticsearch::Async::Bulk::VERSION = '1.12';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
@@ -118,7 +118,7 @@ sub reindex {
     my $transform = $self->_doc_transformer($params);
 
     if ( ref $src eq 'HASH' ) {
-        $src = $self->_hash_to_scroll( $src, $transform );
+        $src = $self->_hash_to_scroll( {%$src}, $transform );
     }
     elsif ( blessed($src) && $src->isa('Search::Elasticsearch::Scroll') ) {
         my $scroll = $src;
@@ -140,7 +140,7 @@ sub reindex {
         my $deferred = deferred;
         my $weak_cb;
         my $cb = sub {
-            my @docs = $src->();
+            my @docs = grep {defined} $src->();
             return $deferred->resolve
                 unless @docs;
             $self->index( grep {$_} map { $transform->($_) } @docs )
@@ -206,7 +206,7 @@ Search::Elasticsearch::Async::Bulk - A helper module for the Bulk API and for re
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
